package com.njcn.pojo.commons;

import java.util.Date;

public class HistoryData{
	private Date timeId;
	private Long lineIndex;
	private int condition;
	private Double freqDev;//频率限值
	private Double voltageDev;//VOLTAGE_DEV	Double(10)	Not NULL	电压限值
	private Double ubalance;//UBALANCE	Double(10)	Not NULL	电压不平衡限值
	private Double flicker;//FLICKER	Double(10)	Not NULL	闪变限值
    private Double uharm;//谐波电压含有率限值
    public Double getUharm() {
		return uharm;
	}
	public void setUharm(Double uharm) {
		this.uharm = uharm;
	}
	public Double getIharm() {
		return iharm;
	}
	public void setIharm(Double iharm) {
		this.iharm = iharm;
	}
	private Double iharm;//谐波电流限值

	public void setTime(Date time) {
		this.time = time;
	}

	public Date getTime() {
		return time;
	}

	private Date time;
	
	public Double getFreqDev() {
		return freqDev;
	}
	public void setFreqDev(Double freqDev) {
		this.freqDev = freqDev;
	}
	public Double getVoltageDev() {
		return voltageDev;
	}
	public void setVoltageDev(Double voltageDev) {
		this.voltageDev = voltageDev;
	}
	public Double getUbalance() {
		return ubalance;
	}
	public void setUbalance(Double ubalance) {
		this.ubalance = ubalance;
	}
	public Double getFlicker() {
		return flicker;
	}
	public void setFlicker(Double flicker) {
		this.flicker = flicker;
	}
	public Double getUaberrance() {
		return uaberrance;
	}
	public void setUaberrance(Double uaberrance) {
		this.uaberrance = uaberrance;
	}
	private Double uaberrance;//UABERRANCE	Double(10)	Not NULL	电压畸变限值

	public Long getLineIndex() {
		return lineIndex;
	}
	public void setLineIndex(Long lineIndex) {
		this.lineIndex = lineIndex;
	}
	public int getCondition() {
		return condition;
	}
	public void setCondition(int condition) {
		this.condition = condition;
	}
	private Double aAvrValue;
	private Double bAvrValue;
	private Double cAvrValue;
	private Double aMaxValue;
	private Double bMaxValue;
	private Double cMaxValue;
	private Double aMinValue;
	private Double bMinValue;
	private Double cMinValue;
	private Double aCP95Value;
	private Double bCP95Value;
	private Double cCP95Value;
	private Double fAvrValue;
	private Double fMaxValue;
	private Double fMinValue;
	private Double fCP95Value;
	
	public Date getTimeId() {
		return timeId;
	}
	public void setTimeId(Date timeId) {
		this.timeId = timeId;
	}
	public Double getaAvrValue() {
		return aAvrValue;
	}
	public void setaAvrValue(Double aAvrValue) {
		this.aAvrValue = aAvrValue;
	}
	public Double getbAvrValue() {
		return bAvrValue;
	}
	public void setbAvrValue(Double bAvrValue) {
		this.bAvrValue = bAvrValue;
	}
	public Double getcAvrValue() {
		return cAvrValue;
	}
	public void setcAvrValue(Double cAvrValue) {
		this.cAvrValue = cAvrValue;
	}
	public Double getaMaxValue() {
		return aMaxValue;
	}
	public void setaMaxValue(Double aMaxValue) {
		this.aMaxValue = aMaxValue;
	}
	public Double getbMaxValue() {
		return bMaxValue;
	}
	public void setbMaxValue(Double bMaxValue) {
		this.bMaxValue = bMaxValue;
	}
	public Double getcMaxValue() {
		return cMaxValue;
	}
	public void setcMaxValue(Double cMaxValue) {
		this.cMaxValue = cMaxValue;
	}
	public Double getaMinValue() {
		return aMinValue;
	}
	public void setaMinValue(Double aMinValue) {
		this.aMinValue = aMinValue;
	}
	public Double getbMinValue() {
		return bMinValue;
	}
	public void setbMinValue(Double bMinValue) {
		this.bMinValue = bMinValue;
	}
	public Double getcMinValue() {
		return cMinValue;
	}
	public void setcMinValue(Double cMinValue) {
		this.cMinValue = cMinValue;
	}
	public Double getaCP95Value() {
		return aCP95Value;
	}
	public void setaCP95Value(Double aCP95Value) {
		this.aCP95Value = aCP95Value;
	}
	public Double getbCP95Value() {
		return bCP95Value;
	}
	public void setbCP95Value(Double bCP95Value) {
		this.bCP95Value = bCP95Value;
	}
	public Double getcCP95Value() {
		return cCP95Value;
	}
	public void setcCP95Value(Double cCP95Value) {
		this.cCP95Value = cCP95Value;
	}
	public Double getfAvrValue() {
		return fAvrValue;
	}
	public void setfAvrValue(Double fAvrValue) {
		this.fAvrValue = fAvrValue;
	}
	public Double getfMaxValue() {
		return fMaxValue;
	}
	public void setfMaxValue(Double fMaxValue) {
		this.fMaxValue = fMaxValue;
	}
	public Double getfMinValue() {
		return fMinValue;
	}
	public void setfMinValue(Double fMinValue) {
		this.fMinValue = fMinValue;
	}
	public Double getfCP95Value() {
		return fCP95Value;
	}
	public void setfCP95Value(Double fCP95Value) {
		this.fCP95Value = fCP95Value;
	}

	@Override
	public String toString() {
		return "HistoryData{" +
				"timeId=" + timeId +
				", lineIndex=" + lineIndex +
				", condition=" + condition +
				", freqDev=" + freqDev +
				", voltageDev=" + voltageDev +
				", ubalance=" + ubalance +
				", flicker=" + flicker +
				", uharm=" + uharm +
				", iharm=" + iharm +
				", time=" + time +
				", uaberrance=" + uaberrance +
				", aAvrValue=" + aAvrValue +
				", bAvrValue=" + bAvrValue +
				", cAvrValue=" + cAvrValue +
				", aMaxValue=" + aMaxValue +
				", bMaxValue=" + bMaxValue +
				", cMaxValue=" + cMaxValue +
				", aMinValue=" + aMinValue +
				", bMinValue=" + bMinValue +
				", cMinValue=" + cMinValue +
				", aCP95Value=" + aCP95Value +
				", bCP95Value=" + bCP95Value +
				", cCP95Value=" + cCP95Value +
				", fAvrValue=" + fAvrValue +
				", fMaxValue=" + fMaxValue +
				", fMinValue=" + fMinValue +
				", fCP95Value=" + fCP95Value +
				'}';
	}
}